@@ -6,7 +6,6 @@ import logging
 from datetime import datetime, timezone, timedelta
 from shutil import which
 import click
-from prettytable import PrettyTable
 from kospex_core import Kospex, GitRepo
 import kospex_utils as KospexUtils
 from kospex_git import KospexGit
@@ -19,7 +18,7 @@ KospexUtils.init()
 kospex = Kospex()
 log = logging.getLogger(__name__)
 #logging.basicConfig(filename='example.log', encoding='utf-8', level=logging.DEBUG)
-VERSION = "0.0.13" # This value should align with the pyproject.toml version for pip
+VERSION = "0.0.15" # This value should align with the pyproject.toml version for pip
 
 @click.group()
 def cli():
@@ -484,17 +483,28 @@ def deps(repo, file, directory, out, dev):
         print("Please specify either a '-repo', '-directory' or a '-file'.")
 
 @cli.command("sca")
-@click.option('-repo', type=GitRepo(), help="File path to git repo.")
-@click.option('-file', type=click.Path(exists=True), help="Package file to assess.")
-@click.option('-dev', is_flag=True, default=False, help="Include dev/test dependencies. EXPERIMENTAL.")
+@click.option('-repo', type=GitRepo(), help="NOT IMPLEMENTED - File path to git repo.")
+@click.option('-dev', is_flag=True, default=True, help="Include dev/test dependencies. EXPERIMENTAL.")
+@click.option('-save', is_flag=True, default=True, help="Save results to kospex DB.")
 @click.option('-out', type=click.STRING, help="filename to write CSV results to.")
-@click.argument('param', required=False, type=click.STRING)
-def sca(repo, file, dev, out, param):
+@click.argument('file_path', required=False, type=click.Path(exists=True))
+def sca(repo, dev, save, out, file_path):
     """
     Run software composition analysis (SCA) tasks
     """
-    print("\nEXPERIMENTAL FEATURE: SCA\n\n")
-    print(f"{param}")
+    print("\nEXPERIMENTAL FEATURE: SCA\n")
+    params = locals()
+    params['print_table'] = True
+
+    if repo:
+        print("NOT implemented")
+        exit(1)
+
+    if file_path:
+         results = kospex.dependencies.assess(file_path,**params)
+    else:
+        print("Either -repo REPO or file_path is required.\n")
+
 
 @cli.command("author-tech")
 @click.option('-author_email', type=click.STRING)
@@ -779,7 +789,9 @@ def groups(name,add,remove,delete,show,file,value,email,repo):
 @click.option('-days', type=int, default=90, help='Committed in X days is considered active.(default 90)')
 @click.option('-window', type=int, default=365, help='Days to consider for orphaned repos. (default 365)')
 @click.option('-server', type=click.STRING, help="Git server to query.")
-def orphans(days,window,server):
+@click.option('-target-list', type=click.Path(exists=True),
+    help="A file containing repos to check.")
+def orphans(days,window,server,target_list):
     """
     Find orphaned repos.
 
@@ -795,8 +807,23 @@ def orphans(days,window,server):
     active_devs = kospex.active_developers(**params)
     active_set = set(map(lambda item: item['author'], active_devs))
 
-    # Find all the repos in the database
-    repos = kospex.kospex_query.repos(server=server)
+    # repos will contain an array of dicts, we need the _repo_id
+    repos = []
+
+    if target_list:
+        # Process the file
+        with open(target_list, 'r') as file:
+                    for line in file:
+                        # Skip empty lines
+                        kospex.git.set_remote_url(line)
+                        repo_id = kospex.git.repo_id
+                        if repo_id:
+                            # Create dict with _repo_id key and add to repos array
+                            repo_dict = {"_repo_id": repo_id}
+                            repos.append(repo_dict)
+    else:
+        # Find all the repos in the database
+        repos = kospex.kospex_query.repos(server=server)
 
     now_utc = datetime.now(timezone.utc)
     from_date = now_utc - timedelta(days=window)
@@ -808,19 +835,18 @@ def orphans(days,window,server):
     # Loop through every repo
     for r in repos:
         # find all the authors in the last 'window' days
-        print(f'\n{r["_repo_id"]}')
         row = []
         row.append(r["_repo_id"])
-
+        print(f"repo_id: {r['_repo_id']}")
         commits = kospex.kospex_query.commits(
             repo_id=r["_repo_id"],
             after=from_date.strftime("%Y-%m-%dT%H:%M:%S%z"))
 
-        #print(f"Commits: {len(commits)}")
         committers = set([c['committer_email'] for c in commits])
         row.append(len(committers))
 
         intersection_count = len(committers.intersection(active_set))
+
         row.append(intersection_count)
 
         print(f"Present: {intersection_count}, Total: {len(committers)} in 12 months.")
@@ -840,23 +866,37 @@ def orphans(days,window,server):
             working_knowledge += 1
 
         table.add_row(row)
+        print()
 
     print()
     print(table)
     print(f"\nOrphaned: {orphaned} | Working Knowledge: {working_knowledge} | Total: {len(repos)}")
     print(f"Orphaned: {orphaned/len(repos)*100:.2f}% | Working Knowledge: {working_knowledge/len(repos)*100:.2f}%\n")
 
+    print()
+
 @cli.command("metadata")
 @click.option('-file_type', type=click.STRING, help="Only returns files of this file type.")
 @click.option('-repo_id', type=click.STRING, help="repo_id to query kospex DB for metadata.")
 @click.option('-sync', type=click.BOOL, help="Sync metadata to kospex DB.")
 def metadata(file_type,repo_id,sync):
-    """ Find file metadata and tags.
+    """
+    Find file metadata and tags.
     """
     dir = os.getcwd()
 
     if repo_id:
         dir = None
+    else:
+        # Check we're in a repo
+        if not kospex.git.is_git_repo(dir):
+            print(f"\n{dir} is NOT a git repo")
+            dir_base = KospexUtils.find_git_base(dir)
+            if dir_base:
+                print(f"Did you mean {dir_base}??")
+            else:
+                print("Can't find a Git repo in any parent directories either.")
+            exit(1)
 
     if file_type and sync:
         print("Can only sync on a directory, with no file_type specified.")
@@ -875,7 +915,6 @@ def version():
     """Print the version of Kospex CLI."""
     click.echo(f"Kospex CLI version {VERSION}")
 
-
 @cli.command("system-status")
 def status():
     """
