@@ -11,8 +11,8 @@ from prettytable import PrettyTable, from_db_cursor
 from kospex_git import KospexGit, MissingGitDirectory
 import kospex_utils as KospexUtils
 import kospex_schema as KospexSchema
-#import kospex_query as KospexQuery
 from kospex_query import KospexQuery, KospexData
+from kospex_dependencies import KospexDependencies
 #from kospex_mergestat import KospexMergeStat
 import panopticas
 
@@ -39,6 +39,7 @@ class Kospex:
         self.kospex_db = KospexSchema.connect_or_create_kospex_db()
         #self.mergestat = KospexMergeStat()
         self.kospex_query = KospexQuery(kospex_db=self.kospex_db)
+        self.dependencies = KospexDependencies(kospex_db=self.kospex_db, kospex_query=self.kospex_query)
 
     def set_repo_dir(self, directory):
         """ Set the repo directory """
@@ -800,6 +801,8 @@ class Kospex:
 
             table.add_row(KospexUtils.get_values_by_keys(row, table.field_names))
 
+            print(row)
+
             # Handle the format for sync data, only with repo_dir
             # We hould have raised a ValueError at the top of the method
             #if sync:
@@ -907,7 +910,13 @@ class Kospex:
                     #row['_mtime'] = os.path.getmtime(row['Filename'])
                     # Set this entry to the latest. Required for tech landscape queries
                     row['latest'] = 1
-                    data_rows.append(self.git.add_git_to_dict(row))
+
+                    # We only want to add files which are managed by Git
+                    file_path = row.get("Provider")
+                    if files.get(file_path):
+                        data_rows.append(self.git.add_git_to_dict(row))
+                    else:
+                        print(f"file_path/Provider : {file_path}, not managed by Git")
 
                 self.kospex_db.table(KospexSchema.TBL_FILE_METADATA).upsert_all(data_rows,
                     pk=["Provider","hash","_repo_id"]
@@ -1123,3 +1132,17 @@ class Kospex:
         table = KospexUtils.get_keyvalue_table(config)
 
         return table
+
+    def delete_repo_id_from_table(self,table,repo_id):
+        """
+        Remove all rows in a table for the given repo_id
+        """
+        if table not in KospexSchema.KOSPEX_TABLES:
+            raise ValueError(f"table: {table} is not a Kospex table")
+
+        kd = KospexData(kospex_db=self.kospex_db)
+        kd.delete()
+        kd.from_table(table)
+        kd.where("_repo_id","=",repo_id)
+        print(kd.generate_sql())
+        return kd.execute()
