@@ -7,6 +7,7 @@ import base64
 import csv
 from datetime import datetime, timezone, timedelta
 from dateutil import parser
+from collections import Counter, OrderedDict
 from prettytable import PrettyTable
 from dotenv import load_dotenv
 
@@ -25,6 +26,17 @@ KOSPEX_CONFIG_ITEMS = [
     "KOSPEX_CONFIG"
 ]
 
+DEFAULT_STATUS_THRESHOLDS = OrderedDict({
+    "Single day": 1,
+    "< 3 months": 90,
+    "< 6 months": 180,
+    "< 1 year": 365,
+    "< 2 years": 730,
+    #"5+ years": 1825
+})
+
+DEFAULT_MAX_STATUS = "2+ Years"
+
 def is_git(directory):
     """Simple directory check to see if it's a git repo"""
     git_path = f"{directory}/.git/"
@@ -473,7 +485,9 @@ def get_last_commit_info(filename,remote=None):
     try:
         # Get the last commit for the file
         os.chdir(file_dir)
-        last_cmd = f"git log -1 --pretty=format:'%H|%ad|%cd' --date=iso-strict -- {basefile}"
+        basefile_quoted = shlex.quote(basefile)
+
+        last_cmd = f"git log -1 --pretty=format:'%H|%ad|%cd' --date=iso-strict -- {basefile_quoted}"
         if is_dir:
             last_cmd = "git log -1 --pretty=format:'%H|%ad|%cd' --date=iso-strict"
 
@@ -481,14 +495,26 @@ def get_last_commit_info(filename,remote=None):
             shlex.split(last_cmd),
             encoding='utf-8'
         )
-        # Split the output to get commit hash, author date, and committer date
-        commit_hash, author_date, committer_date = commit_info.strip().split('|', 2)
 
         remote = get_git_remote_url(file_dir)
         if remote:
             # remove the .git extension if present
             remote = remote.removesuffix('.git')
 
+        # Check we actually have a git result
+        if not commit_info:
+            default['repo'] = remote
+            # Set a flag for unmanaged
+            default['unmanaged'] = True
+            # TODO - fix to debug logging
+            print(f"{filename} does not appear to be managed by git.")
+            return default
+
+        # If we're here, we must have gotten a git result
+
+        # Split the output to get commit hash, author date, and committer date
+        commit_hash, author_date, committer_date = commit_info.strip().split('|', 2)
+
         os.chdir(original_dir)
 
         return {
@@ -506,6 +532,7 @@ def get_last_commit_info(filename,remote=None):
     except Exception as e:
         print(f"An unexpected error occurred: {e} for {filename}, potentially not managed by git.")
         default['error'] = "Potentially not managed by git"
+        default['unmanaged'] = True
     finally:
         os.chdir(original_dir)
 
@@ -1268,3 +1295,72 @@ def encode_base64(data):
         return encoded
     except:
         return None
+
+
+
+def get_status(days: int, thresholds: OrderedDict = None) -> str:
+    """
+    Determine status based on the number of days and configured thresholds.
+
+    Args:
+        days: Integer representing number of days
+        thresholds: OrderedDict with status labels as keys and day thresholds as values
+
+    Returns:
+        String representing the status
+    """
+    if thresholds is None:
+        # thresholds = OrderedDict({
+        #     "Single day": 1,
+        #     "< 3 months": 90,
+        #     "< 6 months": 180,
+        #     "< 1 year": 365,
+        #     "< 2 years": 730,
+        #     "5+ years": 1825
+        # })
+        thresholds = DEFAULT_STATUS_THRESHOLDS
+
+    # Handle case where days is less than the first threshold
+    if days <= list(thresholds.values())[0]:
+        return list(thresholds.keys())[0]
+
+    # Iterate through thresholds to find the correct status
+    prev_threshold = 0
+    for status, threshold in thresholds.items():
+        if prev_threshold < days <= threshold:
+            return status
+        prev_threshold = threshold
+
+    # If days is greater than all thresholds, return the last status
+    #return list(thresholds.keys())[-1]
+    return "2+ Years"
+
+def get_status_distribution(data):
+    """
+    Take a list of Dicts, and calculate the percentages based on the
+    DEFAULT_STATUS_THRESHOLDS categories
+    Return an Order list of thresholds like
+    "Single day" : 45.2
+    """
+
+    tenure_status = [entry['tenure_status'] for entry in data]
+
+    # Count occurrences of each status
+    status_counts = Counter(tenure_status)
+    total_count = len(tenure_status)
+
+    # Calculate percentages
+    distribution = OrderedDict()
+    all_thresholds = DEFAULT_STATUS_THRESHOLDS
+
+    # TODO - See what our max threshold should be if any
+    all_thresholds[DEFAULT_MAX_STATUS] = 20000
+
+    for threshold in all_thresholds:
+        count = status_counts[threshold]
+        if count:
+            distribution[threshold] = round((count / total_count) * 100, 2)
+        else:
+            distribution[threshold] = 0
+
+    return distribution
